@@ -14,38 +14,19 @@
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-from M2Crypto import EC
-from base64 import b64encode, urlsafe_b64decode, urlsafe_b64encode
+from M2Crypto import EC, Rand
+from base64 import urlsafe_b64decode, urlsafe_b64encode
 from hashlib import sha256
+import os
 
 PUB_KEY_DER_PREFIX = "3059301306072a8648ce3d020106082a8648ce3d030107034200" \
     .decode('hex')
 
 
-def b64_split(der):
-    b64 = b64encode(der)
-    return '\n'.join([b64[i:i + 64] for i in range(0, len(b64), 64)])
-
-
 def pub_key_from_der(der):
     return EC.pub_key_from_der(PUB_KEY_DER_PREFIX + der)
 
 
-def update_all(cipher, from_buf, to_buf):
-    while True:
-        buf = from_buf.read()
-        if not buf:
-            break
-        to_buf.write(cipher.update(buf))
-    to_buf.write(cipher.final())
-    return to_buf.getvalue()
-
-
-def zeropad(data, blksize=8):
-    padded = data + ('\0' * ((blksize - len(data)) % blksize))
-    return padded
-
-
 def websafe_decode(data):
     if isinstance(data, unicode):
         data = data.encode('utf-8')
@@ -61,3 +42,10 @@ def sha_256(data):
     h = sha256()
     h.update(data)
     return h.digest()
+
+
+Rand.rand_seed(os.urandom(1024))
+
+
+def rand_bytes(n_bytes):
+    return Rand.rand_bytes(n_bytes)
